package com.parrot.docdown;

import com.parrot.docdown.data.ArtifactDetails;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;

public class DocdownArtifactFiles {

    private static DocdownArtifactFiles instance;

    public static synchronized DocdownArtifactFiles getInstance(DocdownOption docdownOption) {
        if (instance == null) {
            instance = new DocdownArtifactFiles(docdownOption);
        }
        return instance;
    }

    public static synchronized DocdownArtifactFiles getInstance() {
        if (instance == null)
        {
            throw new RuntimeException("DocdownArtifactFiles is not initialized");
        }
        return instance;
    }

    /*****************************************************************************************************/

    private String absolutePath;
    private HashMap<String, ArtifactDetails> artifactFiles = new HashMap<>();

    public DocdownArtifactFiles(DocdownOption docdownOption) {

        Collection<Path> srcDirs = docdownOption.getJavaSrcDirs();
        for (Path srcDir : srcDirs) {
            absolutePath = srcDir.toAbsolutePath().toString();
            try {
                Files.list(srcDir).filter(path -> path.toString().endsWith(".log")).forEach(this::addArtifact);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    private void addArtifact(Path path) {
        String logFileName = path.getFileName().toString();
        // System.out.println("Process Artifact Log: " + logFileName);
        try {
            String[] logFileNameParts = logFileName.split("___");

            String groupId = logFileNameParts[1];
            String artifactId = logFileNameParts[2];
            String version = logFileNameParts[3];
            ArtifactDetails artifactDetails = new ArtifactDetails( groupId,  artifactId,  version);
            List<String> lines = Files.readAllLines(path);

            for (String line: lines) {
                line = line.trim();
                String[] data = line.split(": ");
                if (data.length == 2) {
                    if (data[0].equalsIgnoreCase("inflating")) {
                        try {
                            String javaClassName = data[1].substring(data[1].indexOf("androidx"))
                                    .replace("/", ".");
                            javaClassName = javaClassName.substring(0, javaClassName.lastIndexOf(".java"));
                            System.out.println(javaClassName);
                            artifactFiles.put(javaClassName, artifactDetails);
                        } catch (Exception e) {
                            System.out.println("Error: Invalid File: " + data[1]);
                        }
                    } else if (data[0].equalsIgnoreCase("archive")) {
                        // not needed archive
                    } else if (data[0].equalsIgnoreCase("creating")) {
                        // not needed archive
                    } else {
                        System.out.println("Error: Unusable Artifact line in file: " + path.getFileName());
                        System.out.println(line);
                    }
                } else {
                    System.out.println("Error: Invalid Artifact line in file: " + path.getFileName());
                    System.out.println(line);
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public ArtifactDetails getArtifactDetails(String qualifiedClassName) {
        return artifactFiles.get(qualifiedClassName);
    }
}
