package com.parrot.docdown;

import com.parrot.docdown.data.ArtifactDetails;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;

public class DocdownArtifactMapping {

    private static DocdownArtifactMapping instance;

    public static synchronized DocdownArtifactMapping getInstance(DocdownOption docdownOption) {
        if (instance == null) {
            instance = new DocdownArtifactMapping(docdownOption);
        }
        return instance;
    }

    public static synchronized DocdownArtifactMapping getInstance() {
        if (instance == null)
        {
            throw new RuntimeException("DocdownArtifactMapping is not initialized");
        }
        return instance;
    }

    /*****************************************************************************************************/

    private String absolutePath;
    private HashMap<String, String> artifactMapping = new HashMap<>();
    private HashMap<String, String> classMapping = new HashMap<>();
    private HashMap<String, String> packageMapping = new HashMap<>();

    public DocdownArtifactMapping(DocdownOption docdownOption) {

        Collection<Path> srcDirs = docdownOption.getJavaSrcDirs();
        for (Path srcDir : srcDirs) {
            absolutePath = srcDir.toAbsolutePath().toString();
            try {
                Files.list(srcDir).filter(path -> path.toString().endsWith("artifact-mapping.csv")).forEach(this::addArtifactMappings);
                Files.list(srcDir).filter(path -> path.toString().endsWith("class-mapping.csv")).forEach(this::addClassMappings);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    private void addClassMappings(Path path) {
        try {
            List<String> lines = Files.readAllLines(path);
            // String content = StringUtils.join(lines, "\r\n");
            // System.out.println (content);
            for (String line: lines) {
                try {
                    String[] mappingData = line.split(",");
                    String mappingClass = mappingData[0];
                    String androidxClass = mappingData[1].trim(); // Incl. groupId
                    System.out.println ("Add class mapping for: " + androidxClass + "=>" + mappingClass);
                    classMapping.put(androidxClass, mappingClass);
                    String androidXPackage = getPackage(androidxClass);
                    String mappingPackage = getPackage(mappingClass);
                    packageMapping.put(androidXPackage, mappingPackage);
                    System.out.println ("Add packageMapping " + androidXPackage + "=>" + mappingPackage);
                } catch (Exception e ) {
                    e.printStackTrace();
                    System.out.println ("Error: Invalid mapping line");
                    System.out.println (line);
                    // First linc of class mapping is invalid
                    // because it is a header line
                    // System.exit(0);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private String getPackage(String className) {
        String ret = className.substring(0, className.lastIndexOf("."));
        return ret;
    }

    private void addArtifactMappings(Path path) {
        try {
            List<String> lines = Files.readAllLines(path);
            // String content = StringUtils.join(lines, "\r\n");
            // System.out.println (content);
            for (String line: lines) {
                try {
                    String[] mappingData = line.split(",");
                    String mapping = mappingData[0];
                    String androidxArtifactId = mappingData[1].trim(); // Incl. groupId
                    System.out.println ("Add artifact mapping for: " + androidxArtifactId + "=>" + mapping);
                    artifactMapping.put(androidxArtifactId, mapping);
                } catch (Exception e ) {
                    System.out.println ("Error: Invalid mapping line");
                    System.out.println (line);
                    System.exit(0);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public String getArtifactMapping(String key) {
        return artifactMapping.get(key);
    }

    public String getClassMapping(String key) {
        return classMapping.get(key);
    }

    public String getPackageMapping(String key) {
        return packageMapping.get(key);
    }
}
