package com.parrot.docdown;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.Collection;
import java.util.HashMap;

public class DocdownSourceFiles {

    private static DocdownSourceFiles instance;

    public static synchronized DocdownSourceFiles getInstance(DocdownOption docdownOption) {
        if (instance == null) {
            instance = new DocdownSourceFiles(docdownOption);
        }
        return instance;
    }

    public static synchronized DocdownSourceFiles getInstance() {
        if (instance == null)
        {
            throw new RuntimeException("DocdownSourceFiles is not initialized");
        }
        return instance;
    }

    /*****************************************************************************************************/

    private String absolutePath;
    private HashMap<String,Path> javaFiles = new HashMap<>();

    public DocdownSourceFiles(DocdownOption docdownOption) {

        Collection<Path> srcDirs = docdownOption.getJavaSrcDirs();
        for (Path srcDir : srcDirs) {
            absolutePath = srcDir.toAbsolutePath().toString();
            // System.out.println("############" + srcDir.toAbsolutePath().toString());
            try {
                Files.find(Paths.get(srcDir.toUri()),
                        Integer.MAX_VALUE,
                        (filePath, fileAttr) -> fileAttr.isRegularFile())
                        .forEach(this::addFile);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    private void addFile(Path path) {
        String fileId = path.toString().substring(absolutePath.length() + 1);
        fileId = fileId.replace(File.separator,".");
        fileId = fileId.substring(0, fileId.length()-5);
        javaFiles.put(fileId, path);
    }

    public HashMap<String,Path> getJavaFiles() {
        return javaFiles;
    }
}
