/*
 * Copyright (C) 2013-2013 Nicolas Christe
 * Copyright (C) 2013-2013 Parrot S.A.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 *
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.parrot.docdown.generator.html;

import com.parrot.docdown.DocdownDoclet;
import com.parrot.docdown.generator.DefaultGenerator;
import org.rendersnake.HtmlAttributes;
import org.rendersnake.HtmlCanvas;
import org.rendersnake.Renderable;
import java.text.SimpleDateFormat;
import java.util.Date;

import java.io.IOException;

import static org.rendersnake.HtmlAttributesFactory.class_;
import static org.rendersnake.HtmlAttributesFactory.href;
import static org.rendersnake.HtmlAttributesFactory.onClick;

public abstract class PageContentRenderable implements Renderable {

    private final static boolean ESCAPE_CHARS = true; 

    protected final DefaultGenerator generator;

    public PageContentRenderable(DefaultGenerator generator) {
        this.generator = generator;
    }

    @Override
    public final void renderOn(HtmlCanvas html) throws IOException {
        Date now = new Date();
        String formatString = "EEE, d MMM yyyy HH:mm:ss Z";
        SimpleDateFormat dateFormatter = new SimpleDateFormat(formatString);
        html.div(class_("content"));
        doRenderOn(html);
        // HtmlAttributes consentsUpdateAttr = href("").addScript("onclick", "return klaro.show(klaroConfig, true)", ESCAPE_CHARS);
        // HtmlAttributes consentsResetAttr = href("").addScript("onclick", "klaro.getManager().resetConsents();location.reload()", ESCAPE_CHARS);
        // html.div(class_("footer")).write("Generated by ").a(href("https://github.com/nicolaschriste/docdown"))
        //        .content("Docdown " + DocdownDoclet.version)._div();
        html.div(class_("footer"))
                .write("Generated " + dateFormatter.format(now) + " by ")
                .a(href("https://jentsch.io/")).content("Michael Jentsch")
                .write(" - ")
                .a(href("/privacy-policy.html")).content("Privacy Policy")
                .write(" - ")
                .a(href("/legal-details.html")).content("Legal Details")
                // .write(" - ")
                // .a(consentsUpdateAttr).content("Review / update consents")
                // .write(" - ")
                // .a(consentsResetAttr).content("Reset consents")
                ._div();
        html._div();
    }

    protected abstract void doRenderOn(HtmlCanvas html) throws IOException;
}
